Crate monster_maker_core

Crate monster_maker_core 

Core types for the Monster Maker ecosystem.

This crate provides the core types usable by other crates in the Monster Maker ecosystem. The crate contains several modules, each one containing the logic for a separate core building block. See individual module documentation for use of each of their respective types.

Modules

monster
Definition of a monster.
species
Definition of a species.
type
Monster types and their interactions with each other.